@@ -379,8 +379,7 @@ class Database:
         self._nodes = Table(
             'nodes',
             self._metadata,
-            Column('id', Integer, primary_key=True),
-            Column('bibcode', String(20)),
+            Column('id', String(20)),
             Column('author', String(255)),
             Column('title', String(255)),
             Column('start', Float),
